# Fact Sheet Completeness
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness#introduction)
  * [Completion Score Calculation](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness#completion-score-calculation)
  * [Modifying Completion Weights](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness#modifying-completion-weights)


The fact sheet completion score measures the extent of required data filled out for a fact sheet, ensuring data accuracy and completeness. It is based on assigned weights to fields, subsections, and sections.
